require 'thor'
require 'marksman'

module Marksman
  class CLI < Thor

    desc 'generate FILE [OUTPUT DIRECTORY]', 'generates a presentation from a markdown file'
    long_desc <<-LONGDESC
      `marsksman generate file.md` will parse the markdown file and 
      create a presentation in the folder 'public'

      You can optionally specify the folder where the presentation is stored
      as a second parameter.

      > $ marksman FILE.md output
    LONGDESC
    method_option :theme, desc: 'override the theme in the presentation', aliases: ['-t']
    def generate(file, target = 'public')
      Marksman::Writer.new(file, target, options[:theme]).generate
    end

    desc 'watch FILE [OUTPUT DIRECTORY]', 'same as generate, but watches the file and regenerates it on each change'
    method_option :theme, desc: 'override the theme in the presentation', aliases: ['-t']
    def watch(file, target = 'public')
      Marksman::Watcher.new(file, target, options[:theme]).watch
    end

  end
end
